;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "eask-mode" "20251231.1607"
  "Major mode for editing Eask files."
  '((emacs "24.3")
    (eask  "0.1.0"))
  :url "https://github.com/emacs-eask/eask-mode"
  :commit "0970dc6f4f8008d58261e36b9b824a0ffa6b9882"
  :revdesc "0970dc6f4f80"
  :keywords '("lisp" "eask")
  :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
  :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
